@@ -42,10 +42,14 @@ use warnings;
 use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{
-    COOKIE_QUOTE MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
+    COOKIE_QUOTE
+    MINIMUM_PERL
+    TOKEN_LITERAL
+    TOKEN_UNKNOWN
+    @CARP_NOT
 };
 
-our $VERSION = '0.055';
+our $VERSION = '0.063';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
